lxml package — lxml documentation

Skip to main content
`Ctrl`+`K`

# lxml package

## Subpackages

- lxml.html package
- lxml.isoschematron package

## Submodules

- lxml.ElementInclude module
- lxml.builder module
- lxml.cssselect module
- lxml.doctestcompare module
- lxml.etree module
- lxml.objectify module
- lxml.sax module

## Module contents

lxml.get_include()

  Returns a list of header include paths (for lxml itself, libxml2 and libxslt) needed to compile C code against lxml if it was built with statically linked libraries.